"use strict";

// Extends moleculer error
const { MoleculerError } = require('moleculer').Errors;

// Errors types
const types = {
	// Entities
	entityExists: {
		type: "ENTITY_EXIST",
		message: "The entity that you try to save almost exists"
	},
	entityNotExists: {
		type: "ENTITY_NOT_EXIST",
		message: "The entity that you try to get not exists"
	},
	// Mains on collections
	notMainOnCollection: {
		type: "NOT_MAIN_ON_COLLECTION",
		message: "The collection does not have a main value"
	},
};

// Entities
class EntityExistsError extends MoleculerError {

	/**
	 * Creates an entity exists error.
	 * 
	 * @param {*} data Conditions.
	 */
	constructor(data) {
		const type = types.entityExists;
		super(type.message, 409, type.type, data);
	}
};

class EntityNotExistsError extends MoleculerError {

	/**
	 * Creates an entity not exists error.
	 * 
	 * @param {*} data Conditions.
	 */
	constructor(data) {
		const type = types.entityNotExists;
		super(type.message, 404, type.type, data);
	}
};

// Mains on collections
class NotMainOnCollection extends MoleculerError {

	/**
	 * Creates a not main on collection error.
	 * 
	 * @param {*} data Conditions.
	 */
	constructor(data) {
		const type = types.notMainOnCollection;
		super(type.message, 400, type.type, data);
	}
};

module.exports = {
	EntityExistsError,
	EntityNotExistsError,
	NotMainOnCollection
};
